==> 0.0.7.tar.gz: android/src/main/kotlin/com/blue/flutter_plugin/FlutterPlugin.kt <==
package com.blue.flutter_plugin

import android.os.Build
import androidx.annotation.NonNull
import androidx.annotation.RequiresApi
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result


/** FlutterPlugin */
class FlutterPlugin: FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "flutter_plugin")
    channel.setMethodCallHandler(this)
  }

  @RequiresApi(Build.VERSION_CODES.M)
  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result){
      val mac: String = (call.argument<String>("mac")).toString()
      val pwd: String = (call.argument<String>("pwd")).toString()
      val config: String = (call.argument<String>("config")).toString()
      val newPwd: String = (call.argument<String>("newPwd")).toString()
      OpenApi().onClick(call.method.toInt(),mac,pwd,config,newPwd)

      result.success("Android ${"去调用蓝牙锁"}")
  }
//          if (call.method == "1") {
//
//
//
//          } else {
//            result.notImplemented()
//          }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}

==> 0.1.0.tar.gz: android/src/main/kotlin/com/blue/flutter_plugin/FlutterPlugin.kt <==
package com.blue.flutter_plugin

import android.os.Build
import androidx.annotation.NonNull
import androidx.annotation.RequiresApi
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result


/** FlutterPlugin */
class FlutterPlugin: FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "flutter_plugin")
    channel.setMethodCallHandler(this)
  }

  @RequiresApi(Build.VERSION_CODES.M)
  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result){
      val mac: String = (call.argument<String>("mac")).toString()
      val pwd: String = (call.argument<String>("pwd")).toString()
      val config: String = (call.argument<String>("config")).toString()
      val newPwd: String = (call.argument<String>("newPwd")).toString()


      result.success(OpenApi().onClick(call.method.toInt(),mac,pwd,config,newPwd))
  }
//          if (call.method == "1") {
//
//
//
//          } else {
//            result.notImplemented()
//          }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}
